<?php

defined( 'ABSPATH' ) || exit;


class WC_Jetlinez_Order_Notifyz_Bulk
{

	public function register()
    {
		add_action( 'wc_jetlinez_order_notifyz_settings_form_bottom_send', [ $this, 'bulkForm' ] );
		add_action( 'wc_jetlinez_order_notifyz_settings_form_admin_notices', [ $this, 'bulkNotice' ], 10 );

		if ( WC_Jetlinez_Order_Notifyz()->Options( 'enable_buyer' ) ) {
			add_action( 'admin_footer', [ $this, 'bulkScript' ], 10 );
			add_action( 'load-edit.php', [ $this, 'bulkAction' ] );
		}
	}


	public function bulkForm()
    {
        ?>
		<div class="notice notice-info below-h2">
            <p>با استفاده از قسمت ارسال اعلان ، میتوانید آزمایش کنید که آیا پنل اعلان شما به خوبی به افزونه متصل شده است یا خیر.
            </p>
        </div>
        <form class="initial-form" id="order-notifyz-woo-send-notify-bulk-form" method="post" action="<?php echo admin_url( 'admin.php?page=wc-jetlinez-order-notifyz&tab=send' ) ?>">

			<?php wp_nonce_field( 'wc_jetlinez_order_notifyz_send_nonce', '_wpnonce' ); ?>

            <p>
                <label for="wc_jetlinez_order_notifyz_mobile">شماره دریافت کننده</label><br>
                <input type="text" name="wc_jetlinez_order_notifyz_mobile" id="wc_jetlinez_order_notifyz_mobile"
                       value="<?php echo esc_attr( $_POST['wc_jetlinez_order_notifyz_mobile'] ?? null ); ?>"
                       style="direction:ltr; text-align:left; width:100% !important;"/><br>
                <span>شماره موبایل دریافت کننده اعلان را وارد کنید. شماره ها را با کاما (,) جدا نمایید.</span>
            </p>

            <p>
                <label for="wc_jetlinez_order_notifyz_message">متن اعلان</label><br>
                <textarea name="wc_jetlinez_order_notifyz_message" id="wc_jetlinez_order_notifyz_message" rows="10" style="width:100% !important"><?php echo ! empty( $_POST['wc_jetlinez_order_notifyz_message'] ) ? esc_attr( $_POST['wc_jetlinez_order_notifyz_message'] ) : ''; ?></textarea><br>
                <span>متن دلخواهی که میخواهید به دریافت کننده ارسال کنید را وارد کنید.</span>
            </p>

            <p>
                <input type="submit" class="button button-primary" name="wc_jetlinez_order_notifyz_send" value="ارسال اعلان">
            </p>
        </form>
		<?php
	}


	public function bulkNotice()
    {
		if ( isset( $_POST['wc_jetlinez_order_notifyz_send'] ) ) {

			if ( ! wp_verify_nonce( $_POST['_wpnonce'] ?? null, 'wc_jetlinez_order_notifyz_send_nonce' ) ) {
				wp_die( 'خطایی رخ داده است.' );
			}

			$data = [];
			$data['type']    = 1;
			$data['mobile']  = $mobiles = ! empty( $_POST['wc_jetlinez_order_notifyz_mobile'] ) ? explode( ',', sanitize_text_field( $_POST['wc_jetlinez_order_notifyz_mobile'] ) ) : [];
			$data['message'] = ! empty( $_POST['wc_jetlinez_order_notifyz_message'] ) ? sanitize_textarea_field( $_POST['wc_jetlinez_order_notifyz_message'] ) : '';

			$response = WC_Jetlinez_Order_Notifyz()->SendNotify( $data );

			if ( $response === true ) { ?>
                <div class="notice notice-success below-h2">
                    <p>اعلان با موفقیت ارسال شد.<br><strong>تعداد مخاطبین با حذف شماره های
                            تکراری </strong>=> <?php echo count( $mobiles ) . ' شماره '; ?></p>
                </div>
				<?php
				return true;
			} ?>

            <div class="notice notice-error below-h2">
                <p><strong>خطا: </strong>اعلان ارسال نشد. پاسخ وبسرویس:
					<?php echo esc_attr ( $response ); ?>
                </p>
            </div>
			<?php
		}

		return false;
	}


	public function bulkScript()
    {
		global $post_type;
		if ( 'shop_order' == $post_type ) : ?>
            <script type="text/javascript">
                jQuery(function () {
                    jQuery('<option>').val('send_notify').text('ارسال اعلان دسته جمعی').appendTo("select[name='action']");
                    jQuery('<option>').val('send_notify').text('ارسال اعلان دسته جمعی').appendTo("select[name='action2']");
                });
            </script>
		<?php
		endif;
	}


	public function bulkAction()
    {
		$wp_list_table = _get_list_table( 'WP_Posts_List_Table' );
		$action        = $wp_list_table->current_action();
		if ( $action != 'send_notify' ) {
			return;
		}

		$post_ids = array_map( 'absint', (array) $_REQUEST['post'] );
		$mobiles  = [];
		foreach ( $post_ids as $order_id ) {
			$mobiles[] = WC_Jetlinez_Order_Notifyz()->buyerMobile( $order_id );
		}

		$mobiles = implode( ',', array_unique( array_filter( $mobiles ) ) );

		echo '<form method="POST" name="wc_jetlinez_order_notifyz_posted_form" action="' . admin_url( 'admin.php?page=wc-jetlinez-order-notifyz&tab=send' ) . '">
		<input type="hidden" value="' . esc_attr ( $mobiles ) . '" name="wc_jetlinez_order_notifyz_mobile" />
		</form>
		<script language="javascript" type="text/javascript">document.wc_jetlinez_order_notifyz_posted_form.submit(); </script>';
		exit();
	}

}

new WC_Jetlinez_Order_Notifyz_Bulk();