<?php

defined( 'ABSPATH' ) || exit;


class WC_Jetlinez_Order_Notifyz_Contacts
{

	public function register()
    {
		add_action( 'wc_jetlinez_order_notifyz_settings_form_bottom_contacts', [ $this, 'contactsTable' ] );
		add_action( 'init', [ $this, 'createTable' ] );
		add_action( 'wp_ajax_change_notify_text', [ $this, 'changeNotifyTextCallback' ] );
	}


	public static function groupName( $group_id, $product_id, $cond = true )
    {
		$groups = self::getGroups( $product_id, false, $cond );

		return isset( $groups[ $group_id ] ) ? $groups[ $group_id ] : '';
	}


	public static function getGroups( $product_id, $check = true, $cond = true )
    {
		$groups = [];
		if ( ! $check || ! WC_Jetlinez_Order_Notifyz()->ProductHasProp( $product_id, 'is_on_sale' ) ) {
			if ( ! $cond || WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_onsale', $product_id ) ) {
				$groups['_onsale'] = WC_Jetlinez_Order_Notifyz()->getValue( 'notif_onsale_text', $product_id );
			}
		}

		if ( ! $check || ! WC_Jetlinez_Order_Notifyz()->ProductHasProp( $product_id, 'is_in_stock' ) ) {
			if ( ! $cond || WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_notif_no_stock', $product_id ) ) {
				$groups['_in'] = WC_Jetlinez_Order_Notifyz()->getValue( 'notif_no_stock_text', $product_id );
			}
		}

		if ( ! $check || WC_Jetlinez_Order_Notifyz()->ProductHasProp( $product_id, 'is_not_low_stock' ) ) {
			if ( ! $cond || WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_notif_low_stock', $product_id ) ) {
				$groups['_low'] = WC_Jetlinez_Order_Notifyz()->getValue( 'notif_low_stock_text', $product_id );
			}
		}

		foreach ( explode( PHP_EOL, (string) WC_Jetlinez_Order_Notifyz()->getValue( 'notif_options', $product_id ) ) as $option ) {
			$options = explode( ":", $option, 2 );
			if ( count( $options ) == 2 ) {
				$groups["$options[0]"] = $options[1];
			}
		}

		return array_filter( $groups );
	}


	public static function getContactByMobile( $product_id, $mobile )
    {
		$table = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table();

		$product_id = intval( $product_id );

		$mobile = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::prepareMobile( $mobile );

		global $wpdb;

		return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$table} WHERE product_id=%d AND mobile LIKE '%s'", $product_id, "%$mobile%" ), ARRAY_A );
	}


	public static function getContactsMobiles( int $product_id, string $group )
    {
		global $wpdb;

			$table  = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table();
			$query  = "SELECT `mobile` FROM `{$table}` WHERE product_id=%d";
			$query .= ' AND ( `groups` LIKE %s )';

        $group_name = '%' . $wpdb->esc_like( $group ) . '%';

         $mobiles = $wpdb->get_col( $wpdb->prepare( $query,  $product_id, $group_name)   );

        $mobiles = array_unique( array_filter( $mobiles ) );


		return $mobiles;
    }


	public function createTable()
    {
		if ( get_option( 'wc_jetlinez_order_notifyz_table_contacts_created' ) ) {
			return;
		}

		if ( ! function_exists( 'dbDelta' ) ) {
			require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
		}

		global $wpdb;

		$charset_collate = '';
		if ( ! empty( $wpdb->charset ) ) {
			$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
		}
		if ( ! empty( $wpdb->collate ) ) {
			$charset_collate .= " COLLATE $wpdb->collate";
		}

		$table = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table();
		dbDelta( "CREATE TABLE IF NOT EXISTS {$table} (
			`id` mediumint(8) unsigned NOT NULL auto_increment,
			`product_id` mediumint(8) unsigned,
			`mobile` VARCHAR(250),
			`groups` VARCHAR(250),
			PRIMARY KEY  (id)
		) $charset_collate;" );

		update_option( 'wc_jetlinez_order_notifyz_table_contacts_created', '1' );
	}

	public static function insertContact( $data )
    {
		if ( empty( $data['product_id'] ) || empty( $data['mobile'] ) || empty( $data['groups'] ) ) {
			return false;
		}

		global $wpdb;

		return $wpdb->insert( WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table(), [
			'product_id' => intval( $data['product_id'] ),
			'mobile'     => WC_Jetlinez_Order_Notifyz()->modifyMobile( $data['mobile'] ),
			'groups'     => self::prepareGroups( $data['groups'] ),
		], [ '%d', '%s', '%s' ] );
	}


	private static function prepareGroups( $groups )
    {
		if ( ! is_array( $groups ) ) {
			$groups = explode( ',', (string) $groups );
		}

		$groups = array_map( 'sanitize_text_field', $groups );
		$groups = array_map( 'trim', $groups );
		$groups = array_unique( array_filter( $groups ) );
		$groups = implode( ',', $groups );

		return $groups;
	}


	public function contactsTable()
    {
		$updated = get_option( 'wc_jetlinez_order_notifyz_table_contacts_updated' );
		if ( ! $updated ) { ?>
            <div class="notice notice-info below-h2">
                <p>
                    <strong>
                        در حال انتقال دیتابیس مشترکین خبرنامه سایت شما از جدول post_meta به یک جدول مستقل هستیم.
                        این عمل با توجه به حجم مشترکین شما ممکن است کمی زمانبر باشد.
                        لطفا لحظات دیگری پس از انتقال کامل مشترکین مراجعه نمایید.
                    </strong>
                </p>
            </div>
			<?php return;
		} elseif ( $updated == '1' ) { ?>
            <div class="notice notice-success is-dismissible below-h2">
                <p>
                    <strong>
                        انتقال دیتابیس مشترکین خبرنامه سایت شما از جدول post_meta به یک جدول مستقل با موفقیت انجام شد.
                    </strong>
                </p>
            </div>
			<?php update_option( 'wc_jetlinez_order_notifyz_table_contacts_updated', '2' );
		}

		if ( isset( $_GET['edit'] ) ) {
			$this->editContact( intval( $_GET['edit'] ) );
		} elseif ( isset( $_GET['add'] ) ) {
			$this->addContact( intval( $_GET['add'] ) );
		} else {
			$list = new WC_Jetlinez_Order_Notifyz_Contacts_List_Table();
			$list->prepare_items();

			echo '<style type="text/css">';
			echo '.wp-list-table .column-id { width: 5%; }';
			echo '</style>';


			$product_id = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::request_product_id( true );
			$product_id = count( $product_id ) == 1 ? reset( $product_id ) : 0;

			if ( ! empty( $product_id ) && $title = get_the_title( $product_id ) ) {
				echo sprintf( '<h1>مشترکین محصول "%s"</h1>', esc_attr( $title ) ) . '<br><br>';
			}

			$query_args = [ 'add' => $product_id ];
			if ( ! empty( $product_id ) ) {
				$query_args['product_id'] = $product_id;
			}

			$add_url = add_query_arg( $query_args, admin_url( 'admin.php?page=wc-jetlinez-order-notifyz&tab=contacts' ) ); ?>
            <a class="page-title-action" href="<?php echo esc_url( $add_url ); ?>">افزودن مشترک جدید</a>

			<?php if ( ! empty( $_GET['product_id'] ) || isset( $_GET['add'] ) || isset( $_GET['edit'] ) ) : ?>
                <a class="page-title-action"
                   href="<?php echo remove_query_arg( [ 'product_id', 'add', 'edit' ] ); ?>">
                    بازگشت به لیست همه مشترکین
                </a>
			<?php endif; ?>

            <form method="post">
                <input type="hidden" name="page" value="WC_Jetlinez_Order_Notifyz_Contacts_list_table">
				<?php
				$list->search_box( 'جستجوی شماره موبایل', 'search_id' );
				$list->display();
				?>
            </form>
		<?php } ?>

        <script type="text/javascript">
            jQuery(document).ready(function ($) {
                $('.delete a, a.delete, .button.action').on('click', function (e) {
                    var action1 = $('select[name="action"]').val();
                    var action2 = $('select[name="action2"]').val();
                    if ($(this).is('a') || action1 === 'bulk_delete' || action2 === 'bulk_delete') {
                        if (!confirm('آیا از انجام عملیات حذف مطمئن هستید؟ این عمل غیرقابل برگشت است.')) {
                            e.preventDefault();
                            return false;
                        }
                    }
                });
            });
        </script>
		<?php
	}


	private function editContact( $contact_id = 0 )
    {
		$operation  = empty( $contact_id ) ? 'add' : 'edit';
		$return_url = remove_query_arg( [ 'add', 'edit', 'added' ] );

		$data = $operation == 'edit' ? self::getContactById( $contact_id ) : [];

		if ( $operation == 'edit' ) {
			$product_id = ! empty( $data['product_id'] ) ? intval( $data['product_id'] ) : 0;
		} else {
			$product_id = intval( $_GET['add'] ?? 0 );
		}

		if ( ! empty( $_POST['_wpnonce'] ) ) {

			if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'wc_jetlinez_order_notifyz_contact_nonce' ) ) {
				wp_die( 'خطایی رخ داده است.' );
			}

			$mobile = sanitize_text_field( $_POST['mobile'] ?? null );

			if ( empty( $mobile ) ) {
				$error = 'شماره موبایل الزامی است.';
			} elseif ( ! WC_Jetlinez_Order_Notifyz()->validateMobile( $mobile ) ) {
				$error = 'شماره موبایل وارد شده معتبر نیست.';
			}

			$groups = self::prepareGroups( $_POST['groups'] );

			if ( empty( $groups ) ) {
				$error = 'انتخاب حداقل یک گروه الزامی است.';
			}

			if ( empty( $error ) ) {

				$params = [
					'product_id' => $product_id,
					'mobile'     => $mobile,
					'groups'     => $groups,
				];

				if ( $operation == 'edit' ) {
					$save = self::updateContact( array_merge( [ 'id' => $contact_id ], $params ) );
				} else {
					$save = self::insertContact( $params );
				}

				if ( $save !== false ) {
					if ( $operation == 'edit' ) {
						$saved = true;
					} else {
						global $wpdb;
						$contact_id = $wpdb->insert_id;
						wp_redirect( add_query_arg( [ 'edit' => $contact_id, 'added' => 'true' ], $return_url ) );
						exit();
					}
				} else {
					$error = 'در حین ذخیره خطایی رخ داده است. مجددا تلاش کنید.';
				}
			}

			if ( ! empty( $error ) ) { ?>
                <div class="notice notice-error below-h2">
                    <p><strong>خطا: </strong><?php echo esc_attr ( $error ); ?></p>
                </div>
				<?php
			}
		} else {
			$mobile = ! empty( $data['mobile'] ) ? WC_Jetlinez_Order_Notifyz()->modifyMobile( $data['mobile'] ) : '';
			$groups = ! empty( $data['groups'] ) ? $data['groups'] : '';
		}

		$contact_groups = array_map( 'strval', explode( ',', $groups ) );
		$contact_groups = array_map( 'trim', $contact_groups );

		if ( ! empty( $saved ) || ! empty( $_GET['added'] ) ) { ?>
            <div class="notice notice-success below-h2">
                <p><strong>مشترک ذخیره شد.</strong>
                    <a href="<?php echo esc_url( $return_url ); ?>">بازگشت به لیست مشترکین</a>
                </p>
            </div>
			<?php
		}

		$title = $operation == 'edit' ? 'ویرایش مشترک خبرنامه محصول "%s"' : 'افزودن مشترک جدید برای خبرنامه محصول "%s"'; ?>
        <h3><?php printf( $title, get_the_title( $product_id ) ); ?></h3>

        <form action="<?php echo remove_query_arg( [ 'added' ] ); ?>" method="post">
            <table class="form-table">
                <tbody>
                <tr>
                    <th><label for="mobile">شماره موبایل</label></th>
                    <td><input type="text" id="mobile" name="mobile" value="<?php echo esc_attr ( $mobile ); ?>"
                               style="text-align: left; direction: ltr"></td>
                </tr>
                <tr>
                    <th><label for="mobile">گروه ها</label></th>
                    <td>
						<?php
						$all_groups    = (array) WC_Jetlinez_Order_Notifyz_Contacts::getGroups( $product_id, false, false );
						$active_groups = (array) WC_Jetlinez_Order_Notifyz_Contacts::getGroups( $product_id, false, true );

						foreach ( $all_groups as $group => $label ) {
							$group = strval( $group ); ?>
                            <label for="groups_<?php echo esc_attr( $group ); ?>">
                                <input type="checkbox" name="groups[]" id="groups_<?php echo esc_attr( $group ); ?>"
                                       value="<?php echo esc_attr( $group ); ?>" <?php checked( in_array( $group, $contact_groups ) ) ?>>
								<?php
								echo esc_attr( $label );
								if ( ! in_array( $group, array_keys( $active_groups ) ) ) {
									echo ' (غیرفعال)';
								}
								?>
                            </label><br>
							<?php
						}
						?>
                    </td>
                </tr>
                </tbody>
            </table>

			<?php
			wp_nonce_field( 'wc_jetlinez_order_notifyz_contact_nonce', '_wpnonce' );
			$title = $operation == 'edit' ? 'بروز رسانی مشترک' : 'افزودن مشترک';
			?>

            <p class="submit">
                <input name="submit" class="button button-primary" value="<?php echo esc_attr( $title ); ?>" type="submit">
                <a href="<?php echo esc_url( $return_url ); ?>" class="button button-secondary">بازگشت</a>

				<?php if ( ! empty( $contact_id ) ) :

					$delete_url = add_query_arg( [
						'action'   => 'delete',
						'item'     => absint( $contact_id ),
						'_wpnonce' => wp_create_nonce( 'wc_jetlinez_order_notifyz_delete_contact' ),
					], $return_url ); ?>

                    <a class="delete" href="<?php echo esc_url( $delete_url ); ?>"
                       style="text-decoration: none; color: red">حذف
                        این مشترک</a>
				<?php endif; ?>
            </p>

        </form>
		<?php
	}


	public static function getContactById( $contact_id )
    {
		global $wpdb;
		$table = WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table();

		return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$table} WHERE id=%d", intval( $contact_id ) ), ARRAY_A );
	}


	public static function updateContact( array $data )
    {
		global $wpdb;

		if ( empty( $data['id'] ) || empty( $data['mobile'] ) || empty( $data['groups'] ) ) {
			return false;
		}

		return $wpdb->update( WC_Jetlinez_Order_Notifyz_Contacts_List_Table::table(), [
			'mobile' => WC_Jetlinez_Order_Notifyz()->modifyMobile( $data['mobile'] ),
			'groups' => self::prepareGroups( $data['groups'] ),
		], [ 'id' => intval( $data['id'] ) ], [ '%s', '%s' ], [ '%d' ] );
	}


	private function addContact( $product_id = 0 )
    {
		if ( ! empty( $product_id ) ) {
			$this->editContact();

			return;
		}
		?>

        <table class="form-table">
            <tbody>
            <tr>
                <th>
                    <label for="select_product_id">یک محصول انتخاب کنید</label>
                </th>
                <td>
                    <select id="select_product_id" class="wc-product-search">
                        <option value="">یک محصول انتخاب کنید</option>
                    </select>
                </td>
            </tr>
            </tbody>
        </table>

        <script type="text/javascript">
            jQuery(document).ready(function ($) {
                $('select#select_product_id').on('change', function () {
                    document.location = '<?php echo remove_query_arg( [ 'add' ] );?>' + "&add=" + $(this).val();
                });
            });
        </script>
		<?php
	}
}

new WC_Jetlinez_Order_Notifyz_Contacts();