<?php

defined( 'ABSPATH' ) || exit;


class WC_Jetlinez_Order_Notifyz_MetaBox
{
	private $enable_metabox = false;
	private $enable_notification = false;
	private $enable_product_admin_notify = false;


	public function register()
    {
		if ( ! is_admin() ) {
			return;
		}

		$this->enable_metabox              = WC_Jetlinez_Order_Notifyz()->Options( 'enable_metabox' );
		$this->enable_notification         = WC_Jetlinez_Order_Notifyz()->Options( 'enable_notif_notify_main' );
		$this->enable_product_admin_notify = WC_Jetlinez_Order_Notifyz()->Options( 'enable_product_admin_notify' );

		if ( $this->enable_metabox || $this->enable_notification || $this->enable_product_admin_notify ) {
			add_action( 'add_meta_boxes', [ $this, 'addMetaBox' ] );
			add_action( 'wp_ajax_wc_jetlinez_order_notifyz_metabox', [ $this, 'ajaxCallback' ] );
		}
	}


	public function addMetaBox( )
    {
		if ( $this->enable_metabox ) {
			
			add_meta_box( 'send_notify_to_buyer', 'ارسال اعلان به مشتری', [
				$this,
				'orderMetaBoxHtml',
			], [
				'shop_order',
				wc_get_page_screen_id( 'shop-order' ),
			], 'side', 'high' );
			
		}

		if ( $this->enable_notification || $this->enable_product_admin_notify ) {
			add_meta_box( 'send_notify_to_buyer', 'ارسال اعلان به مشترکین این محصول', [
				$this,
				'productMetaBoxHtml',
			], 'product', 'side', 'high' );
			
		}
	}


	public function ajaxCallback()
    {
		check_ajax_referer( 'wc_jetlinez_order_notifyz_metabox', 'security' );

		if ( empty( $_POST['post_id'] ) || empty( $_POST['post_type'] ) ) {
			wp_send_json_error( [ 'message' => 'خطای ایجکس رخ داده است.' ] );
		}

		$message = sanitize_text_field( $_POST['message'] ?? '' );

		switch ( $_POST['post_type'] ) {

			case 'shop_order':
				$this->orderMetaBoxResult( intval( $_POST['post_id'] ), $message );
				break;

			case 'product':
				$this->productMetaBoxResult( intval( $_POST['post_id'] ), $message, sanitize_text_field( $_POST['group'] ?? '' ) );
				break;

			default:
				wp_send_json_error( [ 'message' => 'خطای ایجکس رخ داده است.' ] );
		}
	}


	public function orderMetaBoxResult( $order_id, $message )
    {
		$order  = new WC_Order( $order_id );
		$mobile = WC_Jetlinez_Order_Notifyz()->buyerMobile( $order_id );

		$data = [
			'post_id' => $order_id,
			'type'    => 3,
			'mobile'  => $mobile,
			'message' => $message,
		];

		if ( ( $result = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) ) === true ) {
			$order->add_order_note( sprintf( 'اعلان با موفقیت به مشتری با شماره موبایل %s ارسال شد.<br>متن اعلان: %s', $mobile, $message ) );
			wp_send_json_success( [
				'message'    => 'اعلان با موفقیت ارسال شد.',
				'order_note' => WC_Jetlinez_Order_Notifyz()->orderNoteMetaBox( $order ),
			] );

		} else {

			$order->add_order_note( sprintf( 'اعلان به مشتری با شماره موبایل %s ارسال نشد.<br>متن اعلان: %s<br>پاسخ وبسرویس: %s', $mobile, $message, $result ) );
			wp_send_json_error( [
				'message'    => sprintf( 'ارسال اعلان با خطا مواجه شد. %s', $result ),
				'order_note' => WC_Jetlinez_Order_Notifyz()->orderNoteMetaBox( $order ),
			] );

		}
	}


	public function productMetaBoxResult( int $product_id, string $message, string $group )
    {
		if ( empty( $group ) ) {
			wp_send_json_error( [ 'message' => 'یک گروه برای دریافت اعلان انتخاب کنید.' ] );
		}

		if ( $group == '_product_admins' ) {
			$type    = 6;
			$mobiles = array_keys( WC_Jetlinez_Order_Notifyz()->ProductAdminMobiles( $product_id ) );
		} else {

			switch ( $group ) {

				case '_onsale':
					$type = 10;
					break;

				case '_in':
					$type = 12;
					break;

				case '_low':
					$type = 14;
					break;

				default:
					$type = 15;
			}

			$mobiles = WC_Jetlinez_Order_Notifyz_Contacts::getContactsMobiles( $product_id, $group );
		}

		$data = [
			'post_id' => $product_id,
			'type'    => $type,
			'mobile'  => $mobiles,
			'message' => $message,
		];

		if ( ( $result = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) ) === true ) {
			wp_send_json_success( [ 'message' => sprintf( 'اعلان با موفقیت به %s شماره موبایل ارسال شد.', count( $mobiles ) ) ] );
		} else {
			wp_send_json_error( [ 'message' => sprintf( 'ارسال اعلان با خطا مواجه شد. %s', $result ) ] );
		}
	}


	public function orderMetaBoxHtml( $post_or_order_object )
    {
		$order_id = $post_or_order_object instanceof WC_Order ? $post_or_order_object->get_id() : $post_or_order_object->ID;

		$mobile   = WC_Jetlinez_Order_Notifyz()->buyerMobile( $order_id );

		if ( empty( $mobile ) ) {
			echo '<p>شماره ای برای ارسال اعلان وجود ندارد.</p>';

			return;
		}

		if ( ! WC_Jetlinez_Order_Notifyz()->validateMobile( $mobile ) ) {
			echo '<p>شماره موبایل مشتری معتبر نیست.</p>';

			return;
		}

		$this->metaBoxHtml( $order_id, 'shop_order', sprintf( '<p>ارسال اعلان به شماره %s</p>', $mobile ) );
	}

	/*محصول*/
	private function metaBoxHtml( int $post_id, $post_type, $html_above = '', $html_below = '' )
    {
        ?>
		<div id="wc_jetlinez_order_notifyz_metabox_result"></div>

		<?php
            $safemetabox = [
                'a'        => [ 'href' => true, 'title' => true, 'target' => true ],
                'p'        => [],
                'select'   => [ 'id' => true, 'class' => true ],
                'option'   => [ 'value' => true ],
                'label'    => [ 'for' => true ],
                'optgroup' => [
                    'label' => true,
                ],


            ];

            echo wp_kses( $html_above, $safemetabox );
		?>

		<p>
            <textarea rows="5" cols="20" class="input-text" id="wc_jetlinez_order_notifyz_message"
					  name="wc_jetlinez_order_notifyz_message" style="width: 100%; height: 78px;" title=""></textarea>
		</p>

		<?php echo wp_kses( $html_below, $safemetabox ); ?>

		<div class="wide" id="wc_jetlinez_order_notifyz_divider" style="text-align: left">
			<input type="submit" class="button save_order button-primary" name="wc_jetlinez_order_notifyz_submit"
				   id="wc_jetlinez_order_notifyz_submit" value="ارسال اعلان">
		</div>

		<div class="wc_jetlinez_order_notifyz_loading">
			<img src="<?php echo WC_JETLINEZ_ORDER_NOTIFYZ_URL . '/assets/images/ajax-loader.gif'; ?>">
		</div>

		<style type="text/css">
            .wc_jetlinez_order_notifyz_loading {
                position: absolute;
                background: rgba(255, 255, 255, 0.5);
                top: 0;
                left: 0;
                z-index: 9999;
                display: none;
                width: 100%;
                height: 100%;
            }

            .wc_jetlinez_order_notifyz_loading img {
                position: absolute;
                top: 40%;
                left: 47%;
            }

            #wc_jetlinez_order_notifyz_metabox_result {
                padding: 6px;
                width: 93%;
                display: none;
                border-radius: 2px;
                border: 1px solid #fff;
            }

            #wc_jetlinez_order_notifyz_metabox_result.success {
                color: #155724;
                background-color: #d4edda;
                border-color: #c3e6cb;
            }

            #wc_jetlinez_order_notifyz_metabox_result.fault {
                color: #721c24;
                background-color: #f8d7da;
                border-color: #f5c6cb;
            }

            #wc_jetlinez_order_notifyz_divider {
                width: 100%;
                border-top: 1px solid #e9e9e9;
                padding-top: 5px;
            }
		</style>

		<script type="text/javascript">
            jQuery(document).ready(function ($) {
                $('#wc_jetlinez_order_notifyz_submit').on('click', function (e) {
                    e.preventDefault();
                    var notes = $('#woocommerce-order-notes .inside');
                    var result = $('div#wc_jetlinez_order_notifyz_metabox_result');
                    var loading = $('.wc_jetlinez_order_notifyz_loading');
                    loading.show();
                    loading.clone().prependTo(notes);
                    var self = $(this);
                    var post_type = '<?php echo esc_attr( $post_type ); ?>';
                    result.removeClass('fault', 'success');
                    self.attr('disabled', true);
                    $.post('<?php echo admin_url( "admin-ajax.php" );?>', {
                        action: 'wc_jetlinez_order_notifyz_metabox',
                        security: '<?php echo wp_create_nonce( 'wc_jetlinez_order_notifyz_metabox' );?>',
                        post_id: '<?php echo intval( $post_id );?>',
                        post_type: post_type,
                        message: $('#wc_jetlinez_order_notifyz_message').val(),
                        group: $('#select_group').val()
                    }, function (res) {
                        result.addClass(res.success ? 'success' : 'fault').html(res.data.message).show();
                        self.attr('disabled', false);
                        if (typeof res.data.order_note != "undefined" && res.data.order_note.length) {
                            notes.html(res.data.order_note);
                        }
                        loading.hide();
                    });
                });
            });
		</script>
		<?php
	}


	public function productMetaBoxHtml( $post )
    {
		$product_id = $post->ID;

		ob_start(); ?>
		<p>
			<label for="select_group">ارسال اعلان به:</label><br>
			<select name="select_group" class="wc-enhanced-select" id="select_group" style="width: 100%;">

				<?php if ( $this->enable_product_admin_notify ) { ?>
					<option value="_product_admins">به مدیران این محصول</option>
				<?php }

				if ( $this->enable_notification ) {

					$groups = WC_Jetlinez_Order_Notifyz_Contacts::getGroups( $product_id, false, true );

					if ( ! empty( $groups ) ) { ?>
						<optgroup label="به مشترکین گروه های زیر:">
							<?php foreach ( $groups as $code => $text ) { ?>
								<option
										value="<?php echo esc_attr( $code ); ?>"><?php echo esc_attr( $text ); ?></option>
							<?php } ?>
						</optgroup>
					<?php }
				}
				?>

			</select>
		</p>
		<?php
		$html_above = ob_get_clean();

		$html_below = '';
		if ( $this->enable_notification ) {
			$contact_url = admin_url( 'admin.php?page=wc-jetlinez-order-notifyz&tab=contacts&product_id=' . $product_id );
			$html_below  = '<p><a style="text-decoration: none" href="' . $contact_url . '" target="_blank">مشاهده مشترکین خبرنامه این محصول</a></p>';
		}

		$this->metaBoxHtml( $product_id, 'product', $html_above, $html_below );
	}

}

new WC_Jetlinez_Order_Notifyz_MetaBox();