<?php

defined( 'ABSPATH' ) || exit;


class WC_Jetlinez_Order_Notifyz_Orders 
{
	public $SafeJetlinez_Order_Notifyz_WOOCSS = [ 'style' => [] ];
	private $enabled_buyers = false;
	private $enable_super_admin_notify = false;
	private $enable_product_admin_notify = false;

	public function register()
    {
		$this->enabled_buyers              = WC_Jetlinez_Order_Notifyz()->Options( 'enable_buyer' );
		$this->enable_super_admin_notify   = WC_Jetlinez_Order_Notifyz()->Options( 'enable_super_admin_notify' );
		$this->enable_product_admin_notify = WC_Jetlinez_Order_Notifyz()->Options( 'enable_product_admin_notify' );

		if ( $this->enabled_buyers || $this->enable_super_admin_notify || $this->enable_product_admin_notify ) {

			add_filter( 'woocommerce_checkout_fields', [ $this, 'WC_Jetlinez_Order_Notifyz_MobileLabel' ], 0 );
			add_filter( 'woocommerce_billing_fields', [ $this, 'WC_Jetlinez_Order_Notifyz_MobileLabel' ] );

			add_action( 'wp_enqueue_scripts', [ $this, 'WC_Jetlinez_Order_Notifyz_CheckoutScript' ] );
			add_action( 'woocommerce_after_order_notes', [ $this, 'WC_Jetlinez_Order_Notifyz_CheckoutFields' ] );
			add_action( 'woocommerce_checkout_process', [ $this, 'WC_Jetlinez_Order_Notifyz_CheckoutFieldsValidation' ] );
			add_action( 'woocommerce_checkout_update_order_meta', [ $this, 'WC_Jetlinez_Order_Notifyz_SaveNotifyOrderMeta' ] );

			add_action( 'woocommerce_order_status_changed', [ $this, 'WC_Jetlinez_Order_Notifyz_SendOrderNotify' ], 99, 3 );

			add_action( 'woocommerce_checkout_order_processed', [ $this, 'WC_Jetlinez_Order_Notifyz_SendOrderNotify' ], 99, 1 );
			add_action( 'woocommerce_process_shop_order_meta', [ $this, 'WC_Jetlinez_Order_Notifyz_SendOrderNotify' ], 999, 1 );

			add_action( 'woocommerce_resume_order', function () {
				remove_action( 'woocommerce_checkout_order_processed', [ $this, 'WC_Jetlinez_Order_Notifyz_SendOrderNotify' ], 99 );
			} );

			add_filter( 'woocommerce_form_field_wc_jetlinez_order_notifyz_multiselect', [
				'WC_Jetlinez_Order_Notifyz_Helper',
				'multiSelectAndCheckbox',
			], 11, 4 );
			add_filter( 'woocommerce_form_field_wc_jetlinez_order_notifyz_multicheckbox', [
				'WC_Jetlinez_Order_Notifyz_Helper',
				'multiSelectAndCheckbox',
			], 11, 4 );

			if ( is_admin() ) {
				add_action( 'woocommerce_admin_order_data_after_billing_address', [
					$this,
					'WC_Jetlinez_Order_Notifyz_BuyerNotifyDetails',
				], 10, 1 );
				add_action( 'woocommerce_admin_order_data_after_order_details', [ $this, 'WC_Jetlinez_Order_Notifyz_ChangeNotifyTextJS' ] );
				add_action( 'wp_ajax_change_sms_text', [ $this, 'changeNotifyTextCallback' ] );
			}
		}
	}

    
	public function WC_Jetlinez_Order_Notifyz_MobileLabel( $fields )
    {
		$mobile_meta = WC_Jetlinez_Order_Notifyz()->buyerMobileMeta();

		if ( ! empty( $fields[ $mobile_meta ]['label'] ) ) {
			$fields[ $mobile_meta ]['label'] = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_phone_label', $fields[ $mobile_meta ]['label'] );
		}

		if ( ! empty( $fields['billing'][ $mobile_meta ]['label'] ) ) {
			$fields['billing'][ $mobile_meta ]['label'] = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_phone_label', $fields['billing'][ $mobile_meta ]['label'] );
		}

		return $fields;
	}

    
	public function WC_Jetlinez_Order_Notifyz_CheckoutScript()
    {
		if ( ! function_exists( 'is_checkout' ) || ! function_exists( 'wc_enqueue_js' ) ) {
			return;
		}

		if ( WC_Jetlinez_Order_Notifyz()->Options( 'allow_buyer_select_status' ) && is_checkout() ) {

			wp_register_script( 'wc_jetlinez_order_notifyz-frontend-js', WC_JETLINEZ_ORDER_NOTIFYZ_URL . '/assets/js/multi-select.js', [ 'jquery' ], WC_JETLINEZ_ORDER_NOTIFYZ_VERSION, true );
			wp_localize_script( 'wc_jetlinez_order_notifyz-frontend-js', 'wc_jetlinez_order_notifyz',
				[
					'ajax_url'                  => admin_url( 'admin-ajax.php' ),
					'chosen_placeholder_single' => 'گزینه مورد نظر را انتخاب نمایید.',
					'chosen_placeholder_multi'  => 'گزینه های مورد نظر را انتخاب نمایید.',
					'chosen_no_results_text'    => 'هیچ گزینه ای وجود ندارد.',
				]
			);
			wp_enqueue_script( 'wc_jetlinez_order_notifyz-frontend-js' );

			if ( ! WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer' ) ) {
				wc_enqueue_js( "
					jQuery( '#buyer_notify_status_field' ).hide();
					jQuery( 'input[name=buyer_notify_notify]' ).change( function () {
						if ( jQuery( this ).is( ':checked' ) )
							jQuery( '#buyer_notify_status_field' ).show();
						else
							jQuery( '#buyer_notify_status_field' ).hide();
					} ).change();
				" );
			}
		}
	}

    
	public function WC_Jetlinez_Order_Notifyz_CheckoutFields( $checkout )
    {
		if ( ! $this->enabled_buyers || count( WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		echo '<div id="WC_Jetlinez_Order_Notifyz_CheckoutFields">';

		$checkbox_text = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_checkbox_text', 'میخواهم از وضعیت سفارش از طریق اعلان آگاه شوم.' );
		$required      = WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer' );
		if ( ! $required ) {
			woocommerce_form_field( 'buyer_notify_notify',
				[
					'type'        => 'checkbox',
					'class'       => [ 'buyer-notify-notify form-row-wide' ],
					'label'       => $checkbox_text,
					'label_class' => '',
					'required'    => false,
				], $checkout->get_value( 'buyer_notify_notify' )
			);
		}

		if ( WC_Jetlinez_Order_Notifyz()->Options( 'allow_buyer_select_status' ) ) {
			$multiselect_text        = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_select_status_text_top' );
			$multiselect_text_bellow = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_select_status_text_bellow' );
			$required                = WC_Jetlinez_Order_Notifyz()->Options( 'force_buyer_select_status' );
			$mode                    = WC_Jetlinez_Order_Notifyz()->Options( 'buyer_status_mode', 'selector' ) == 'selector' ? 'wc_jetlinez_order_notifyz_multiselect' : 'wc_jetlinez_order_notifyz_multicheckbox';
			woocommerce_form_field( 'buyer_notify_status', [
				'type'        => $mode ? $mode : '',
				'class'       => [ 'buyer-notify-status form-row-wide wc-enhanced-select' ],
				'label'       => $multiselect_text,
				'options'     => WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses( true ),
				'required'    => $required,
				'description' => $multiselect_text_bellow,
			], $checkout->get_value( 'buyer_notify_status' ) );
		}

		echo '</div>';
	}

    
	public function WC_Jetlinez_Order_Notifyz_CheckoutFieldsValidation()
    {
		$mobile_meta = WC_Jetlinez_Order_Notifyz()->buyerMobileMeta();

		$_POST[ $mobile_meta ] = WC_Jetlinez_Order_Notifyz()->modifyMobile( sanitize_text_field( $_POST[ $mobile_meta ] ?? null ) );

		if ( ! $this->enabled_buyers || count( WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		$force_buyer = WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer' );

		if ( ! $force_buyer && ! empty( $_POST['buyer_notify_notify'] ) && empty( $_POST[ $mobile_meta ] ) ) {
			wc_add_notice( 'برای دریافت اعلان می بایست شماره موبایل را وارد نمایید.', 'error' );
		}

		$buyer_selected = $force_buyer || ( ! $force_buyer && ! empty( $_POST['buyer_notify_notify'] ) );

		if ( $buyer_selected && ! WC_Jetlinez_Order_Notifyz()->validateMobile( $_POST[ $mobile_meta ] ?? null ) ) {
			wc_add_notice( 'شماره موبایل معتبر نیست.', 'error' );
		}

		if ( $buyer_selected && empty( $_POST['buyer_notify_status'] ) && WC_Jetlinez_Order_Notifyz()->Options( 'allow_buyer_select_status' ) && WC_Jetlinez_Order_Notifyz()->Options( 'force_buyer_select_status' ) ) {
			wc_add_notice( 'انتخاب حداقل یکی از وضعیت های سفارش دریافت اعلان الزامی است.', 'error' );
		}
	}

    
	public function WC_Jetlinez_Order_Notifyz_SaveNotifyOrderMeta( $order_id )
    {
		if ( ! $this->enabled_buyers || count( WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses() ) <= 0 ) {
			return;
		}

		$order = wc_get_order( $order_id );

		$order->update_meta_data( '_force_enable_buyer', WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer', '__' ) );
		$order->update_meta_data( '_allow_buyer_select_status', WC_Jetlinez_Order_Notifyz()->Options( 'allow_buyer_select_status', '__' ) );

		if ( ! empty( $_POST['buyer_notify_notify'] ) || WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer' ) ) {
			$order->update_meta_data( '_buyer_notify_notify', 'yes' );
		} else {
			$order->delete_meta_data( '_buyer_notify_notify' );
		}

		if ( ! empty( $_POST['buyer_notify_status'] ) ) {
			$statuses = is_array( $_POST['buyer_notify_status'] ) ? array_map( 'sanitize_text_field', $_POST['buyer_notify_status'] ) : sanitize_text_field( $_POST['buyer_notify_status'] );
			$order->update_meta_data( '_buyer_notify_status', $statuses );
		} else {
			$order->delete_meta_data( '_buyer_notify_status' );
		}

		$order->save_meta_data();
	}

    
	public function WC_Jetlinez_Order_Notifyz_BuyerNotifyDetails( WC_Order $order )
    {
		if ( ! $this->enabled_buyers || count( WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses() ) < 0 ) {
			return;
		}

		$mobile = WC_Jetlinez_Order_Notifyz()->buyerMobile( $order->get_id() );

		if ( empty( $mobile ) ) {
			return;
		}

		if ( ! WC_Jetlinez_Order_Notifyz()->validateMobile( $mobile ) ) {
			echo '<p>شماره موبایل مشتری معتبر نیست.</p>';

			return;
		}

		if ( WC_Jetlinez_Order_Notifyz()->maybeBool( $order->get_meta( '_force_enable_buyer' ) ) ) {
			echo '<p>مشتری حق انتخاب دریافت یا عدم دریافت اعلان را ندارد.</p>';
		} else {
			$want_notify = $order->get_meta( '_buyer_notify_notify' );
			echo '<p>آیا مشتری مایل به دریافت اعلان هست : ' . ( WC_Jetlinez_Order_Notifyz()->maybeBool( $want_notify ) ? 'بله' : 'خیر' ) . '</p>';
		}

		echo '<p>';
		if ( WC_Jetlinez_Order_Notifyz()->maybeBool( $order->get_meta( '_allow_buyer_select_status' ) ) ) {

			$buyer_notify_status = (array) $order->get_meta( '_buyer_notify_status' );
			$buyer_notify_status = array_filter( $buyer_notify_status );

			echo 'وضعیت های انتخابی توسط مشتری برای دریافت اعلان : ';
			if ( ! empty( $buyer_notify_status ) ) {
				$statuses = [];
				foreach ( $buyer_notify_status as $status ) {
					$statuses[] = WC_Jetlinez_Order_Notifyz()->statusName( $status );
				}

				echo esc_html( implode( ' - ', $statuses ) );
			} else {
				echo 'وضعیتی انتخاب نشده است.';
			}

		} else {
			echo 'مشتری حق انتخاب وضعیت های دریافت اعلان را ندارد و از تنظیمات افزونه پیروی میکند.';
		}
		echo '</p>';
	}


	public function WC_Jetlinez_Order_Notifyz_SendOrderNotify( int $order_id, $old_status = '', $new_status = 'created' )
    {
		if ( current_action() == 'woocommerce_process_shop_order_meta' ) {
			if ( ! is_admin() ) {
				return;
			}
		} else {
			remove_action( 'woocommerce_process_shop_order_meta', [ $this, 'WC_Jetlinez_Order_Notifyz_SendOrderNotify' ], 999 );
		}

		$new_status = WC_Jetlinez_Order_Notifyz()->modifyStatus( $new_status );

		if ( ! $order_id ) {
			return;
		}

		$order = new WC_Order( $order_id );
		// Customer
		$order_page = ( $_POST['is_shop_order'] ?? null ) == 'true';
		$this->buyerCanGetNotify( $order_id, $new_status );
		if ( ( $order_page && !empty( $_POST['notify_order_send'] ) ) || ( !$order_page && $this->buyerCanGetNotify( $order_id, $new_status ) ) ) {

			$mobile  = WC_Jetlinez_Order_Notifyz()->buyerMobile( $order_id );
			$message = isset( $_POST['notify_order_text'] ) ? sanitize_textarea_field( $_POST['notify_order_text'] ) : WC_Jetlinez_Order_Notifyz()->Options( 'notify_body_' . $new_status );

			$data = [
				'post_id' => $order_id,
				'type'    => 2,
				'mobile'  => $mobile,
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceShortCodes( $message, $new_status, $order ),
			];

			if ( ( $result = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) ) === true ) {
				$order->add_order_note( sprintf( 'اعلان با موفقیت به مشتری با شماره %s ارسال گردید.', $mobile ) );
			} else {
				$order->add_order_note( sprintf( 'اعلان بخاطر خطا به مشتری با شماره %s ارسال نشد.<br>پاسخ وبسرویس: %s', $mobile, $result ) );
			}
		}


		// superAdmin
		if ( $this->enable_super_admin_notify && in_array( $new_status, (array) WC_Jetlinez_Order_Notifyz()->Options( 'super_admin_order_status' ) ) ) {

			$mobile  = WC_Jetlinez_Order_Notifyz()->Options( 'super_admin_phone' );
			$message = WC_Jetlinez_Order_Notifyz()->Options( 'super_admin_notify_body_' . $new_status );

			$data = [
				'post_id' => $order_id,
				'type'    => 4,
				'mobile'  => $mobile,
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceShortCodes( $message, $new_status, $order ),
			];

			if ( ( $result = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) ) === true ) {
				$order->add_order_note( sprintf( 'اعلان با موفقیت به مدیر کل با شماره %s ارسال گردید.', $mobile ) );
			} else {
				$order->add_order_note( sprintf( 'اعلان بخاطر خطا به مدیر کل با شماره %s ارسال نشد.<br>پاسخ وبسرویس: %s', $mobile, $result ) );
			}
		}

		// productAdmin
		if ( $this->enable_product_admin_notify ) {

			$order_products = WC_Jetlinez_Order_Notifyz()->GetProdcutLists( $order, 'product_id' );
			$mobiles        = WC_Jetlinez_Order_Notifyz()->ProductAdminMobiles( $order_products['product_id'], $new_status );

			foreach ( (array) $mobiles as $mobile => $product_ids ) {

				$vendor_items = WC_Jetlinez_Order_Notifyz()->ProductAdminItems( $order_products, $product_ids );
				$message      = WC_Jetlinez_Order_Notifyz()->Options( 'product_admin_notify_body_' . $new_status );

				$data = [
					'post_id' => $order_id,
					'type'    => 5,
					'mobile'  => $mobile,
					'message' => WC_Jetlinez_Order_Notifyz()->ReplaceShortCodes( $message, $new_status, $order, $vendor_items ),
				];

				if ( ( $result = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) ) === true ) {
					$order->add_order_note( sprintf( 'اعلان با موفقیت به مدیر محصول با شماره %s ارسال گردید.', $mobile ) );
				} else {
					$order->add_order_note( sprintf( 'اعلان بخاطر خطا به مدیر محصول با شماره %s ارسال نشد.<br>پاسخ وبسرویس: %s', $mobile, $result ) );
				}
			}
		}
	}

    
	public function buyerCanGetNotify( int $order_id, string $new_status ): bool 
    {
		if ( !$this->enabled_buyers ) {
			return false;
		}

		if ( !$order_id ) {
			return false;
		}

		$order = wc_get_order( $order_id );

		$allowed_status = array_keys( WC_Jetlinez_Order_Notifyz()->GetBuyerAllowedStatuses() );

		if ( is_admin() ) {
			$status      = WC_Jetlinez_Order_Notifyz()->OrderProp( $order, 'status' );
			$created_via = WC_Jetlinez_Order_Notifyz()->OrderProp( $order, 'created_via' );
			if ( $created_via == 'admin' || ! in_array( $status, array_keys( WC_Jetlinez_Order_Notifyz()->GetAllStatuses() ) ) ) {
				$order->update_meta_data( '_force_enable_buyer', WC_Jetlinez_Order_Notifyz()->Options( 'force_enable_buyer', '__' ) );
				$order->update_meta_data( '_allow_buyer_select_status', WC_Jetlinez_Order_Notifyz()->Options( 'allow_buyer_select_status', '__' ) );
				$order->update_meta_data( '_buyer_sms_notify', 'yes' );
				$order->update_meta_data( '_buyer_sms_status', $allowed_status );
				$order->save_meta_data();
			}
		}
		
		if ( !WC_Jetlinez_Order_Notifyz()->validateMobile( WC_Jetlinez_Order_Notifyz()->buyerMobile( $order_id ) ) ) {
			return false;
		}
		
		$buyer_can_get_notify = false;
		
		if ( in_array( $new_status, $allowed_status ) && WC_Jetlinez_Order_Notifyz()->maybeBool( $order->get_meta( '_buyer_sms_notify' ) ) ) {

			$buyer_notify_status = (array) $order->get_meta( '_buyer_sms_status' );
			$allow_select_status = WC_Jetlinez_Order_Notifyz()->maybeBool( $order->get_meta( '_allow_buyer_select_status' ) );

			if ( ! $allow_select_status || in_array( $new_status, $buyer_notify_status ) ) {
				$buyer_can_get_notify = true;
			}
		}

		return apply_filters( 'wc_jetlinez_order_notifyz_buyer_can_get_order_notify', $buyer_can_get_notify, $order, $new_status );
	}

    
	public function WC_Jetlinez_Order_Notifyz_ChangeNotifyTextJS( WC_Order $order )
    {
		if ( $this->enabled_buyers && WC_Jetlinez_Order_Notifyz()->validateMobile( WC_Jetlinez_Order_Notifyz()->buyerMobile( $order->get_id() ) ) ) { ?>
			<script type="text/javascript">
                jQuery(document).ready(function ($) {
                    $("#order_status").change(function () {
						$("#wc_jetlinez_order_notifyz_textbox").html("<img src=\"<?php echo WC_JETLINEZ_ORDER_NOTIFYZ_URL ?>/assets/images/ajax-loader.gif\" />");

						$.ajax({
							url: "<?php echo admin_url( "admin-ajax.php" ) ?>",
							type: "post",
							data: {
								action: "change_sms_text",
								security: "<?php echo wp_create_nonce( "change-sms-text" ) ?>",
								order_id: "<?php echo intval( $order->get_id() ); ?>",
								order_status: $("#order_status").val()
							},
							success: function (response) {
								$("#wc_jetlinez_order_notifyz_textbox").html(response);
							}
						});
                    });
                });
			</script>
			<p class="form-field form-field-wide" id="wc_jetlinez_order_notifyz_textbox_p">
				<span id="wc_jetlinez_order_notifyz_textbox" class="wc_jetlinez_order_notifyz_textbox"></span>
			</p>
			<?php
		}
	}

    
	public function changeNotifyTextCallback()
    {
		check_ajax_referer( 'change-sms-text', 'security' );

		$order_id = intval( $_POST['order_id'] ?? 0 );

		if ( empty( $order_id ) ) {
			die( 'خطای آیجکس رخ داده است.' );
		}

		$new_status = '';

		if ( isset( $_POST['order_status'] ) ) {
			$_order_status = is_array( $_POST['order_status'] ) ? array_map( 'sanitize_text_field', $_POST['order_status'] ) : sanitize_text_field( $_POST['order_status'] );
			$new_status    = WC_Jetlinez_Order_Notifyz()->modifyStatus( $_order_status );
		}

		$order   = new WC_Order( $order_id );
		$message = WC_Jetlinez_Order_Notifyz()->Options( 'notify_body_' . $new_status );
		$message = WC_Jetlinez_Order_Notifyz()->ReplaceShortCodes( $message, $new_status, $order );

		echo '<textarea id="notify_order_text" name="notify_order_text" style="width:100%;height:120px;"> ' . esc_attr( $message ) . ' </textarea>';
		echo '<input type="hidden" name="is_shop_order" value="true" />';

		if ( $this->buyerCanGetNotify( $order_id, $new_status ) ) {
			$notify_checked = 'checked="checked"';
			$description = 'با توجه به تنظیمات و انتخاب ها، مشتری باید این اعلان را دریافت کند. ولی میتوانید ارسال اعلان به وی را از طریق این چک باکس غیرفعال نمایید.';
		} else {
			$notify_checked = '';
			$description = 'با توجه به تنظیمات و انتخاب ها، مشتری نباید این اعلان را دریافت کند. ولی میتوانید ارسال اعلان به وی را از طریق این چک باکس فعال نمایید.';
		}

		echo '<input type="checkbox" id="notify_order_send" class="notify_order_send" name="notify_order_send" value="true" style="margin-top:2px;width:20px; float:right" ' . wp_kses( $notify_checked, $this->SafeJetlinez_Order_Notifyz_WOOCSS ) . '/>
					<label class="notify_order_send_label" for="notify_order_send" >ارسال اعلان به مشتری</label>
					<span class="description">' . esc_attr( $description ) . '</span>';

		die();
	}
    
}

new WC_Jetlinez_Order_Notifyz_Orders();