<?php

defined( 'ABSPATH' ) || exit;

class WC_Jetlinez_Order_Notifyz_Product_Events
{
	private $enable_notification = false;
	private $enable_super_admin_notify = false;
	private $enable_product_admin_notify = false;


	public function register()
    {
		$this->enable_notification         = WC_Jetlinez_Order_Notifyz()->Options( 'enable_notif_notify_main' );
		$this->enable_super_admin_notify   = WC_Jetlinez_Order_Notifyz()->Options( 'enable_super_admin_notify' );
		$this->enable_product_admin_notify = WC_Jetlinez_Order_Notifyz()->Options( 'enable_product_admin_notify' );

		if ( $this->enable_notification || $this->enable_super_admin_notify || $this->enable_product_admin_notify ) {
			add_action( 'init', [ $this, 'init' ] );
		}
	}


	public function init()
    {
		$action = ! empty( $_POST['action'] ) ? str_ireplace( 'woocommerce_', '', sanitize_text_field( $_POST['action'] ) ) : '';
		if ( in_array( $action, [ 'add_variation', 'link_all_variations' ] ) ) {
			return;
		}

		/** onSale **/
		add_action( 'woocommerce_process_product_meta', [ $this, 'notifyIsOnSale' ], 9999, 1 );
		add_action( 'woocommerce_update_product_variation', [ $this, 'notifyIsOnSale' ], 9999, 1 );
		add_action( 'woocommerce_sms_send_onsale_event', [ $this, 'notifyIsOnSale' ] );
		/** inStock **/
		add_action( 'woocommerce_product_set_stock_status', [ $this, 'notifyInStock' ] );
		add_action( 'woocommerce_variation_set_stock_status', [ $this, 'notifyInStock' ] );
		/** outStock **/
		add_action( 'woocommerce_product_set_stock_status', [ $this, 'notifyOutStock' ] );
		add_action( 'woocommerce_variation_set_stock_status', [ $this, 'notifyOutStock' ] );
		/** lowStock **/
		add_action( 'woocommerce_low_stock', [ $this, 'notifyIsLowStock' ] );
		add_action( 'woocommerce_product_set_stock', [ $this, 'notifyIsLowStock' ] );
		add_action( 'woocommerce_variation_set_stock', [ $this, 'notifyIsLowStock' ] );
	}


	public function notifyIsOnSale( int $product_id )
    {
		$product           = wc_get_product( $product_id );
		$parent_product_id = $product->get_parent_id() ? $product->get_parent_id() : $product->get_id();

		$post_meta   = '_onsale_send';
		$schedule    = 'woocommerce_notify_send_onsale_event';
		$sale_price  = $product->get_sale_price();
		$is_schedule = current_action() == $schedule;

		if ( $sale_price === get_post_meta( $parent_product_id, $post_meta, true ) ) {
			return false;
		} elseif ( ! $is_schedule ) {
			delete_post_meta( $parent_product_id, $post_meta );
		}

		if ( WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_onsale', $parent_product_id ) ) {

			if ( ! $product->is_on_sale() ) {

				if ( ! $is_schedule ) {
					$date_from = WC_Jetlinez_Order_Notifyz()->ProductSalePriceTime( $product_id, 'from' );
					if ( ! empty( $date_from ) && $date_from > strtotime( 'NOW', current_time( 'timestamp' ) ) ) {
						wp_schedule_single_event( $date_from + 3600, $schedule, [ $product_id ] );
					}
				}

				return delete_post_meta( $parent_product_id, $post_meta );
			}

			wp_clear_scheduled_hook( $schedule );

			$data = [
				'post_id' => $parent_product_id,
				'type'    => 9,
				'mobile'  => WC_Jetlinez_Order_Notifyz_Contacts::getContactsMobiles( $parent_product_id, '_onsale' ),
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceTags( 'notif_onsale_notify', $product_id, $parent_product_id ),
			];

			if ( WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) === true ) {
				//return update_post_meta( $parent_product_id, $post_meta, $sale_price );
				//} else {
				//return delete_post_meta( $parent_product_id, $post_meta );
			}

			return update_post_meta( $parent_product_id, $post_meta, $sale_price );
		}
	}


	public function notifyInStock( $product_id )
    {
		$product           = wc_get_product( $product_id );
		$parent_product_id = $product->get_parent_id() ? $product->get_parent_id() : $product->get_id();

		$post_meta = '_in_stock_send';

		if ( ! $product->is_in_stock() ) {
			return delete_post_meta( $parent_product_id, $post_meta );
		}

		if ( WC_Jetlinez_Order_Notifyz()->maybeBool( get_post_meta( $parent_product_id, $post_meta, true ) ) ) {
			return false;
		}

		if ( WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_notif_no_stock', $parent_product_id ) ) {

			$data = [
				'post_id' => $parent_product_id,
				'type'    => 11,
				'mobile'  => WC_Jetlinez_Order_Notifyz_Contacts::getContactsMobiles( $parent_product_id, '_in' ),
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceTags( 'notif_no_stock_notify', $product_id, $parent_product_id ),
			];

			if ( WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) === true ) {
				//return update_post_meta( $parent_product_id, $post_meta, 'yes' );
				//} else {
				//return delete_post_meta( $parent_product_id, $post_meta );
			}

			return update_post_meta( $parent_product_id, $post_meta, 'yes' );
		}
	}


	public function notifyOutStock( $product_id )
    {
		$product           = wc_get_product( $product_id );
		$parent_product_id = $product->get_parent_id() ? $product->get_parent_id() : $product->get_id();

		$post_meta = '_out_stock_send_notify';

		if ( $product->is_in_stock() ) {
			return delete_post_meta( $parent_product_id, $post_meta );
		}

		if ( WC_Jetlinez_Order_Notifyz()->maybeBool( get_post_meta( $parent_product_id, $post_meta, true ) ) ) {
			return false;
		}

		if ( $this->notifyAdminsStocks( $product_id, $parent_product_id, 'out', 7 ) ) {
			//return update_post_meta( $parent_product_id, $post_meta, 'yes' );
			//} else {
			//return delete_post_meta( $parent_product_id, $post_meta );
		}

		return update_post_meta( $parent_product_id, $post_meta, 'yes' );
	}


	private function notifyAdminsStocks( $product_id, $parent_product_id, $status, $type )
    {
		$mobiles = [];
		if ( $this->enable_super_admin_notify ) {
			if ( in_array( $status, (array) WC_Jetlinez_Order_Notifyz()->Options( 'super_admin_order_status' ) ) ) {
				$mobiles = array_merge( $mobiles, explode( ',', WC_Jetlinez_Order_Notifyz()->Options( 'super_admin_phone' ) ) );
			}
		}
		if ( $this->enable_product_admin_notify ) {
			$mobiles = array_merge( $mobiles, array_keys( WC_Jetlinez_Order_Notifyz()->ProductAdminMobiles( $parent_product_id, $status ) ) );
		}

		$mobiles = array_map( 'trim', $mobiles );
		$mobiles = array_unique( array_filter( $mobiles ) );

		if ( ! empty( $mobiles ) ) {
			$data = [
				'post_id' => $parent_product_id,
				'type'    => $type,
				'mobile'  => $mobiles,
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceTags( "admin_{$status}_stock", $product_id, $parent_product_id ),
			];

			return WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) === true;
		}

		return false;
	}


	public function notifyIsLowStock( $product_id )
    {
		if ( 'yes' !== get_option( 'woocommerce_manage_stock' ) ) {
			return false;
		}

		$product           = wc_get_product( $product_id );
		$parent_product_id = $product->get_parent_id() ? $product->get_parent_id() : $product->get_id();
		
		if ( ! WC_Jetlinez_Order_Notifyz()->IsStockManaging( $product ) ) {
			return false;
		}

		$post_meta = '_low_stock_send';

		$quantity = WC_Jetlinez_Order_Notifyz()->ProductStockQty( $product );
		if ( $quantity > get_option( 'woocommerce_notify_low_stock_amount' ) || $quantity <= get_option( 'woocommerce_notify_no_stock_amount' ) ) {
			return delete_post_meta( $parent_product_id, $post_meta );
		}

		if ( WC_Jetlinez_Order_Notifyz()->maybeBool( get_post_meta( $parent_product_id, $post_meta, true ) ) ) {
			return false;
		}

		if ( WC_Jetlinez_Order_Notifyz()->hasNotifCond( 'enable_notif_low_stock', $parent_product_id ) ) {
			$data         = [
				'post_id' => $parent_product_id,
				'type'    => 13,
				'mobile'  => WC_Jetlinez_Order_Notifyz_Contacts::getContactsMobiles( $parent_product_id, '_low' ),
				'message' => WC_Jetlinez_Order_Notifyz()->ReplaceTags( 'notif_low_stock_notify', $product_id, $parent_product_id ),
			];
			$result_users = WC_Jetlinez_Order_Notifyz()->SendNotify( $data ) === true;
		}

		if ( $this->notifyAdminsStocks( $product_id, $parent_product_id, 'low', 8 ) || ! empty( $result_users ) ) {
			//return update_post_meta( $parent_product_id, $post_meta, 'yes' );
			//} else {
			//return delete_post_meta( $parent_product_id, $post_meta );
		}

		return update_post_meta( $parent_product_id, $post_meta, 'yes' );
	}
}

new WC_Jetlinez_Order_Notifyz_Product_Events();