<?php
/**
 * Plugin Name: Jetlinez Order Notifyz for Woocommerce
 * Plugin URI: https://jetlinez.com
 * Description: woocommerce order status.
 * Version: 1.0.0
 * Author: sobelz
 * Author URI: https://sobelz.com
 * WC requires at least: 6.0.0
 * WC tested up to: 8.3.1
 */

defined( 'ABSPATH' ) || exit;


if ( file_exists( dirname( __FILE__ ) . '/vendor/autoload.php' ) )
{
    require_once dirname( __FILE__ ) . '/vendor/autoload.php';
}


if ( file_exists( dirname( __FILE__ ) . '/inc/config/config.php' ) )
{
    require_once dirname( __FILE__ ) . '/inc/config/config.php';
}

add_action( 'admin_init', 'jetlinez_woocommerce_not_exists' );
function jetlinez_woocommerce_not_exists() {
    function jetlinez_woocommerce_notice() {
        $message = sprintf( 'جت لاینز: ووکامرس را نصب و فعال کنید.' );
        printf( '<div class="notice notice-error"><p>%s</p></div>', $message );
    }

    if ( !is_plugin_active('woocommerce/woocommerce.php') ) {
        add_action('admin_notices', 'jetlinez_woocommerce_notice');
        return;
    }
}

register_activation_hook( __FILE__, 'WC_Jetlinez_Order_Notifyz_Activate' );
register_deactivation_hook( __FILE__, 'WC_Jetlinez_Order_Notifyz_Deactivate' );

function WC_Jetlinez_Order_Notifyz_Activate()
{
	delete_option( 'wc_jetlinez_order_notifyz_table_archive' );
	delete_option( 'wc_jetlinez_order_notifyz_table_contacts' );
}

function WC_Jetlinez_Order_Notifyz_Deactivate()
{
	delete_option( 'wc_jetlinez_order_notifyz_table_archive' );
	delete_option( 'wc_jetlinez_order_notifyz_table_contacts' );
}

function WC_Jetlinez_Order_Notifyz()
{
    global $WC_Jetlinez_Order_Notifyz;

    return ( $WC_Jetlinez_Order_Notifyz = WC_Jetlinez_Order_Notifyz_Helper::init() );
}


function WC_Jetlinez_Order_Notifyz_Shortcode( $get = false, $strip_brac = false )
{
    $shortcode = 'wc_jetlinez_order_notifyz';

    if ( $get ) {
        if ( $strip_brac ) {
            return $shortcode;
        }

        return "[$shortcode]";
    }

    echo do_shortcode( "[$shortcode]" );
}


if ( class_exists( 'WC_Jetlinez_Order_Notifyz_Init' ) )
{
    WC_Jetlinez_Order_Notifyz_Init::register();
}


add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wc_jetlinez_order_notifyz_action_links' );

add_action( 'admin_enqueue_scripts', 'wc_jetlinez_order_notifyz_load_admin_style' );

add_action( 'before_woocommerce_init', function() {
    if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
    }
});


function wc_jetlinez_order_notifyz_action_links( $links ) {
    $links = array_merge( array(
        '<a href="' . esc_url( admin_url( '/admin.php?page=wc-jetlinez-order-notifyz' ) ) . '">پیکربندی</a>',
        '<a target="_blank" href="https://jetlinez.com">پشتیبانی</a>'
    ), $links );

    return $links;
}


function wc_jetlinez_order_notifyz_load_admin_style()
{
	wp_enqueue_style( 'wc_jetlinez_order_notifyz_admin_style', plugin_dir_url( __FILE__ ) . 'assets/css/admin-style.css' );
}

