<?php

use Automattic\WooCommerce\Utilities\OrderUtil;

defined( 'ABSPATH' ) || exit;


if ( !class_exists( 'WP_List_Table' ) )
{
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}


class WC_Jetlinez_Order_Notifyz_Archive_List_Table extends WP_List_Table
{
    public static $table = 'wc_jetlinez_order_notifyz_archive';


    public function __construct()
    {
        parent::__construct( [
            'singular' => 'آرشیو اعلان های ووکامرس',
            'plural'   => 'آرشیو اعلان های ووکامرس',
            'ajax'     => false,
        ] );
    }


    public function no_items()
    {
        echo 'موردی یافت نشد.';
    }


    public function column_default( $item, $column_name ): string
    {
        $align = is_rtl() ? 'right' : 'left';

        switch ( $column_name ) {
            case 'reciever':
                return '<div style="direction:ltr !important;text-align:' . $align . ';">' . $item[ $column_name ] . '</div>';
            default:
                if ( is_string( $item[ $column_name ] ) ) {
                    return nl2br( $item[ $column_name ] );
                }

                return print_r( $item[ $column_name ], true );
        }
    }


    public function column_cb( $item ): string
    {
        return sprintf(
            '<input type="checkbox" name="item[]" value="%s" />', $item['id']
        );
    }


    public function column_post_id( $item )
    {
        if ( empty( $item['post_id'] ) ) {
            return '-';
        }

        $post_id = intval( $item['post_id'] );

        $is_order   = OrderUtil::is_order( $post_id, wc_get_order_types() );
        $is_product = get_post_type( $post_id ) == 'product';

        $value = [];

        switch ( true ) {
            case $is_order:
                $edit_title   = 'مدیریت سفارش';
                $filter_title = 'مشاهده آرشیو اعلان های این سفارش';
                $value[]      = 'سفارش #' . $post_id;
                break;

            case $is_product:
                $edit_title   = 'مدیریت محصول';
                $filter_title = 'مشاهده آرشیو اعلان های این محصول';
                $value[]      = 'محصول';
                $value[]      = get_the_title( $post_id );
                break;

            default:
                return '-';
        }

        $actions = [
            'show' => sprintf( '<a target="_blank" href="%s">%s</a>', get_edit_post_link( $post_id ), $edit_title ),
        ];

        $post_id = '<a title="' . $filter_title . '" href="' . add_query_arg( [ 'id' => $post_id ] ) . '">' . implode( ' :: ', $value ) . '</a>';

        return sprintf( '%1$s %2$s', $post_id, $this->row_actions( $actions ) );
    }


    public function column_result( $item )
    {
        $result = ! empty( $item['result'] ) ? $item['result'] : '';

        if ( trim( $result ) == '_ok_' ) {
            $result = 'اعلان با موفقیت ارسال شد.';
        }

        return $result;
    }


    public function column_type( $item )
    {
        if ( empty( $item['type'] ) ) {
            return '-';
        }

        switch ( $item['type'] ) {
            case '1':
                $value = 'ارسال دسته جمعی';
                break;

            case '2':
                $value = 'مشتری - خودکار - سفارش';
                break;

            case '3':
                $value = 'مشتری - دستی - متاباکس سفارش';
                break;

            case '4':
                $value = 'مدیر کل - خودکار - سفارش';
                break;

            case '5':
                $value = 'مدیر محصول - خودکار - سفارش';
                break;

            case '6':
                $value = 'مدیر محصول - دستی - متاباکس محصول';
                break;

            case '7':
                $value = 'مدیران - خودکار - ناموجود شدن';
                break;

            case '8':
                $value = 'مدیران - خودکار - کم بودن موجودی';
                break;

            case '9':
                $value = 'خبرنامه - حراج شدن - اتوماتیک';
                break;

            case '10':
                $value = 'خبرنامه - حراج شدن - دستی';
                break;

            case '11':
                $value = 'خبرنامه - موجود شدن - اتوماتیک';
                break;

            case '12':
                $value = 'خبرنامه - موجود شدن - دستی';
                break;

            case '13':
                $value = 'خبرنامه - کم بودن موجودی - اتوماتیک';
                break;

            case '14':
                $value = 'خبرنامه - کم بودن موجودی - دستی';
                break;

            case '15':
                $value = 'خبرنامه - گزینه های دلخواه - دستی';
                break;

            default:
                $value = '';
        }

        return $value;
    }


    public function column_date( $item ): string
    {
        $delete_nonce = wp_create_nonce( 'wc_jetlinez_order_notifyz_delete_archive' );

        $url = add_query_arg( [
            'action'   => 'delete',
            'item'     => absint( $item['id'] ),
            '_wpnonce' => $delete_nonce,
        ] );

        $actions = [
            'delete' => sprintf( '<a href="%s">حذف</a>', $url ),// @todo escape url
        ];

        $date = date_i18n( 'Y-m-d H:i:s', strtotime( $item['date'] ) );
        $date = WC_Jetlinez_Order_Notifyz()->mayBeJalaliDate( $date );

        return sprintf( '%1$s %2$s', $date, $this->row_actions( $actions ) );
    }


    public function prepare_items()
    {
        $this->_column_headers = [ $this->get_columns(), [], $this->get_sortable_columns() ];
        $this->process_bulk_action();

        $per_page = 20;

        $this->set_pagination_args( [
            'total_items' => $this->record_count(),
            'per_page'    => $per_page,
        ] );

        $this->items = $this->get_items( $per_page, $this->get_pagenum() );
    }


    public function get_columns(): array
    {
        return [
            'cb'       => '<input type="checkbox" />',
            'date'     => 'زمان',
            'post_id'  => 'سفارش / محصول',
            'type'     => 'نوع پیام',
            'message'  => 'متن پیام',
            'reciever' => 'گیرندگان',
            'result'   => 'نتیجه وبسرویس',
        ];
    }


    public function get_sortable_columns(): array
    {
        return [
            'post_id'  => [ 'post_id', false ],
            'type'     => [ 'type', false ],
            'reciever' => [ 'reciever', false ],
            'date'     => [ 'date', false ],
        ];
    }


    public function process_bulk_action()
    {
        $action = $this->current_action();

        if ( 'delete' === $action ) {

            if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'] ?? null, 'wc_jetlinez_order_notifyz_delete_archive' ) ) {
                wp_die( 'خطایی رخ داده است. بعدا تلاش کنید.' );
            }

            $this->delete_item( intval( $_REQUEST['item'] ?? 0 ) );

            echo '<div class="updated notice is-dismissible below-h2"><p>آیتم حذف شد.</p></div>';

        } else if ( $action == 'bulk_delete' ) {

            if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'] ?? null, 'bulk-' . $this->_args['plural'] ) ) {
                wp_die( 'خطایی رخ داده است. بعدا تلاش کنید.' );
            }

            $delete_ids = array_map( 'intval', $_REQUEST['item'] ?? [] );

            foreach ( (array) $delete_ids as $id ) {
                $this->delete_item( $id );
            }

            echo '<div class="updated notice is-dismissible below-h2"><p>آیتم ها حذف شدند.</p></div>';
        }
    }


    public function delete_item( int $id )
    {
        global $wpdb;

        $wpdb->delete( self::table(), [ 'id' => $id ] );

    }


    public static function table(): string
    {
        global $wpdb;

        return $wpdb->prefix . self::$table;
    }


    public function record_count(): int
    {
        global $wpdb;

        if ( ! $this->table_exists() ) {
            return 0;
        }

        return $wpdb->get_var( $this->get_query( true ) );
    }


    private function table_exists()
    {
        global $wpdb;

        $wild   = '%';
        $like   = $wild . $wpdb->esc_like( self::table() ) . $wild;
        $result = $wpdb->get_var( $wpdb->prepare( "SHOW TABLES  LIKE %s", $like ) );

        return ! is_null( $result ) ? 1 : 0;
    }


    private function get_query( $count = false )
    {
        global $wpdb;

        $select = $count ? 'count(*)' : '*';

        $sql = sprintf( "SELECT %s FROM %s", $select, self::table() );

        if ( isset( $_REQUEST['s'] ) ) {
            $s   = ltrim( sanitize_text_field( $_REQUEST['s'] ), '0' );
            $sql .= $wpdb->prepare( " WHERE (`message` LIKE %s OR `reciever` LIKE %s)", '%' . $wpdb->esc_like( $s ) . '%', '%' . $wpdb->esc_like( $s ) . '%', '%' . $wpdb->esc_like( $s ) . '%' );
        }

        if ( ! empty( $_REQUEST['id'] ) ) {
            $post_id = array_map( 'intval', is_array( $_REQUEST['id'] ) ? $_REQUEST['id'] : explode( ',', (string) $_REQUEST['id'] ) );
            $sql     .= ( isset( $s ) ? ' AND' : ' WHERE' ) . ' (`post_id` IN (' . implode( ',', (array) sanitize_text_field( $post_id[0] ) ) . '))';
        }

        if ( ! empty( $_REQUEST['orderby'] ) ) {
            $sql .= $wpdb->prepare( ' ORDER BY %s', sanitize_text_field( $_REQUEST['orderby'] ) );
            $sql .= $_REQUEST['order'] == 'DESC' ? ' DESC' : ' ASC';
        } else {
            $sql .= ' ORDER BY id DESC';
        }

        return $sql;
    }


    public function get_items( int $per_page = 20, int $page_number = 1 )
    {
        global $wpdb;

        if ( ! $this->table_exists() ) {
            return [];
        }

        $query = $this->get_query();
        $query .= $wpdb->prepare( " LIMIT %d, %d ", ( $page_number - 1 ) * $per_page, $per_page );

        return $wpdb->get_results( $query, 'ARRAY_A' );
    }


    public function get_bulk_actions(): array
    {
        return [
            'bulk_delete' => 'حذف',
        ];
    }

}